@@ -1,33 +1,29 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
 /**
  * @var CPartial $this
+ * @var array    $data
  */
 ?>
 
 <script type="text/javascript">
 (() => {
-	document.querySelectorAll('#valuemap-table .element-table-add').forEach((elm) => elm.addEventListener('click',
-		(event) => openAddPopup(event))
+	document.querySelectorAll(`#${'<?= $data['table_id'] ?>'} .element-table-add`).forEach((element) =>
+		element.addEventListener('click', (event) => openAddPopup(event))
 	);
 
 	function openAddPopup(event) {
@@ -70,7 +66,7 @@ var AddValueMap = class {
 			this.row.querySelector(`input[value="${this.data.name}"] ~ a`).focus();
 		}
 		else {
-			document.querySelector('#valuemap-table tbody').append(this.row);
+			document.querySelector(`#${'<?= $data['table_id'] ?>'} tbody`).append(this.row);
 		}
 	}
 
@@ -78,7 +74,7 @@ var AddValueMap = class {
 		const cell = document.createElement('td');
 		const link = document.createElement('a');
 		link.textContent = this.data.name;
-		link.classList.add('wordwrap');
+		link.classList.add('wordbreak');
 		link.href = 'javascript:void(0);';
 		link.addEventListener('click', (e) => {
 			const valuemap_names = [];
@@ -124,7 +120,7 @@ var AddValueMap = class {
 		hellip.innerHTML = '&hellip;';
 		arrow_cell.textContent = '⇒';
 		mappings_table.classList.add('mappings-table');
-		cell.classList.add('wordwrap');
+		cell.classList.add('wordbreak');
 
 		for (let mapping of this.data.mappings) {
 			mapping = {value: '', ...mapping};
