@@ -1,6 +1,6 @@
 <?php declare(strict_types = 0);
 /*
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -112,18 +112,14 @@ foreach ($data['maintenances'] as $maintenanceid => $maintenance) {
 
 	$maintenance_list->addRow([
 		$data['allowed_edit'] ? new CCheckBox('maintenanceids['.$maintenanceid.']', $maintenanceid) : null,
-		(new CCol(
-			(new CLink($maintenance['name']))
-				->addClass('js-edit-maintenance')
-				->setAttribute('data-maintenanceid', $maintenanceid)
-		))->addClass(ZBX_STYLE_WORDBREAK),
+		(new CLink($maintenance['name']))
+			->addClass('js-edit-maintenance')
+			->setAttribute('data-maintenanceid', $maintenanceid),
 		$maintenance['maintenance_type'] ? _('No data collection') : _('With data collection'),
 		zbx_date2str(DATE_TIME_FORMAT, $maintenance['active_since']),
 		zbx_date2str(DATE_TIME_FORMAT, $maintenance['active_till']),
 		$maintenance_status,
-		(new CCol($maintenance['description']))
-			->addClass(ZBX_STYLE_WORDBREAK)
-			->addStyle('max-width: '.ZBX_TEXTAREA_BIG_WIDTH.'px;')
+		$maintenance['description']
 	]);
 }
 
