@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -24,7 +19,8 @@
  */
 
 $form = (new CForm())
-	->setId('preprocessing-test-form');
+	->setId('preprocessing-test-form')
+	->setName('preprocessing_test_form');
 
 if ($data['show_prev']) {
 	$form
@@ -32,30 +28,33 @@ if ($data['show_prev']) {
 		->addVar('upd_prev', '');
 }
 
-foreach ($data['inputs'] as $name => $value) {
+foreach ($data['inputs']['item'] as $name => $value) {
+	if (in_array($name, ['query_fields', 'headers', 'parameters'])) {
+		foreach ($value as $num => $row) {
+			$form->addVar($name.'['.$num.'][name]', $row['name']);
+			$form->addVar($name.'['.$num.'][value]', $row['value']);
+		}
+	}
+	else {
+		$form->addItem((new CInput('hidden', $name, $value))->removeId());
+	}
+}
+
+foreach ($data['inputs']['host'] as $name => $value) {
+	if ($name === 'proxyid') {
+		continue;
+	}
+
 	if ($name === 'interface') {
 		// SNMPv3 additional details about interface.
 		if (array_key_exists('useip', $value)) {
 			$form->addVar('interface[useip]', $value['useip']);
 		}
+
 		if (array_key_exists('interfaceid', $value)) {
 			$form->addVar('interface[interfaceid]', $value['interfaceid']);
 		}
-		continue;
-	}
-	elseif ($name === 'host' && array_key_exists('hostid', $value)) {
-		$form->addVar('hostid', $value['hostid']);
-		continue;
-	}
-	elseif ($name === 'proxy_hostid') {
-		continue;
-	}
-	elseif ($name === 'query_fields' || $name === 'headers' || $name === 'parameters') {
-		foreach (['name', 'value'] as $key) {
-			if (array_key_exists($key, $value)) {
-				$form->addVar($name.'['.$key.']', $value[$key]);
-			}
-		}
+
 		continue;
 	}
 
@@ -101,7 +100,7 @@ if ($data['is_item_testable']) {
 			->addClass('js-host-address-row'),
 		(new CFormField(
 			$data['interface_address_enabled']
-				? (new CTextBox('interface[address]', $data['inputs']['interface']['address'], false,
+				? (new CTextBox('interface[address]', $data['inputs']['host']['interface']['address'], false,
 						CControllerPopupItemTest::INPUT_MAX_LENGTH
 					))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 				: (new CTextBox('interface[address]', '', false, CControllerPopupItemTest::INPUT_MAX_LENGTH))
@@ -112,7 +111,7 @@ if ($data['is_item_testable']) {
 		(new CLabel(_('Port'), 'interface_port'))->addClass('js-host-address-row'),
 		(new CFormField(
 			$data['interface_port_enabled']
-				? (new CTextBox('interface[port]', $data['inputs']['interface']['port'], '', 64))
+				? (new CTextBox('interface[port]', $data['inputs']['host']['interface']['port'], '', 64))
 					->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
 				: (new CTextBox('interface[port]'))
 					->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
@@ -128,7 +127,7 @@ if ($data['is_item_testable']) {
 				(new CSelect('interface[details][version]'))
 					->setId('interface_details_version')
 					->setFocusableElementId('label-interface-details-version')
-					->setValue($data['inputs']['interface']['details']['version'])
+					->setValue($data['inputs']['host']['interface']['details']['version'])
 					->addOptions(CSelect::createOptionsFromArray([
 						SNMP_V1 => _('SNMPv1'),
 						SNMP_V2C => _('SNMPv2'),
@@ -142,8 +141,9 @@ if ($data['is_item_testable']) {
 				->setAsteriskMark()
 				->addClass('js-popup-row-snmp-community'),
 			(new CFormField(
-				(new CTextBox('interface[details][community]', $data['inputs']['interface']['details']['community'],
-					false, CControllerPopupItemTest::INPUT_MAX_LENGTH
+				(new CTextBox('interface[details][community]',
+					$data['inputs']['host']['interface']['details']['community'], false,
+					CControllerPopupItemTest::INPUT_MAX_LENGTH
 				))
 					->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 					->setAriaRequired()
@@ -155,7 +155,7 @@ if ($data['is_item_testable']) {
 				->addClass('js-popup-row-snmp-max-repetition'),
 			(new CFormField(
 					(new CTextBox('interface[details][max_repetitions]',
-						$data['inputs']['interface']['details']['max_repetitions'], false,
+						$data['inputs']['host']['interface']['details']['max_repetitions'], false,
 						CControllerPopupItemTest::INPUT_MAX_LENGTH
 					))
 						->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
@@ -167,8 +167,9 @@ if ($data['is_item_testable']) {
 			(new CLabel(_('Context name'), 'interface[details][contextname]'))
 				->addClass('js-popup-row-snmpv3-contextname'),
 			(new CFormField(
-				(new CTextBox('interface[details][contextname]', $data['inputs']['interface']['details']['contextname'],
-					false, CControllerPopupItemTest::INPUT_MAX_LENGTH
+				(new CTextBox('interface[details][contextname]',
+					$data['inputs']['host']['interface']['details']['contextname'], false,
+					CControllerPopupItemTest::INPUT_MAX_LENGTH
 				))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 			))
 				->addClass(CFormField::ZBX_STYLE_FORM_FIELD_FLUID)
@@ -178,7 +179,7 @@ if ($data['is_item_testable']) {
 				->addClass('js-popup-row-snmpv3-securityname'),
 			(new CFormField(
 				(new CTextBox('interface[details][securityname]',
-					$data['inputs']['interface']['details']['securityname'], false,
+					$data['inputs']['host']['interface']['details']['securityname'], false,
 					CControllerPopupItemTest::INPUT_MAX_LENGTH
 				))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 			))
@@ -190,7 +191,7 @@ if ($data['is_item_testable']) {
 			(new CFormField(
 				(new CSelect('interface[details][securitylevel]'))
 					->setId('interface_details_securitylevel')
-					->setValue($data['inputs']['interface']['details']['securitylevel'])
+					->setValue($data['inputs']['host']['interface']['details']['securitylevel'])
 					->setFocusableElementId('label-interface-details-securitylevel')
 					->addOptions(CSelect::createOptionsFromArray([
 						ITEM_SNMPV3_SECURITYLEVEL_NOAUTHNOPRIV => 'noAuthNoPriv',
@@ -204,8 +205,8 @@ if ($data['is_item_testable']) {
 			(new CLabel(_('Authentication protocol'), 'label-authprotocol'))
 				->addClass('js-popup-row-snmpv3-authprotocol'),
 			(new CFormField(
-				(new CSelect('interfaces[details][authprotocol]'))
-					->setValue((int) $data['inputs']['interface']['details']['authprotocol'])
+				(new CSelect('interface[details][authprotocol]'))
+					->setValue((int) $data['inputs']['host']['interface']['details']['authprotocol'])
 					->setFocusableElementId('label-authprotocol')
 					->addOptions(CSelect::createOptionsFromArray(getSnmpV3AuthProtocols()))
 			))
@@ -216,7 +217,7 @@ if ($data['is_item_testable']) {
 				->addClass('js-popup-row-snmpv3-authpassphrase'),
 			(new CFormField(
 				(new CTextBox('interface[details][authpassphrase]',
-					$data['inputs']['interface']['details']['authpassphrase'], false,
+					$data['inputs']['host']['interface']['details']['authpassphrase'], false,
 					CControllerPopupItemTest::INPUT_MAX_LENGTH
 				))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 			))
@@ -225,8 +226,8 @@ if ($data['is_item_testable']) {
 
 			(new CLabel(_('Privacy protocol'), 'label-privprotocol'))->addClass('js-popup-row-snmpv3-privprotocol'),
 			(new CFormField(
-				(new CSelect('interfaces[details][privprotocol]'))
-					->setValue((int) $data['inputs']['interface']['details']['privprotocol'])
+				(new CSelect('interface[details][privprotocol]'))
+					->setValue((int) $data['inputs']['host']['interface']['details']['privprotocol'])
 					->setFocusableElementId('label-privprotocol')
 					->addOptions(CSelect::createOptionsFromArray(getSnmpV3PrivProtocols()))
 			))
@@ -237,7 +238,7 @@ if ($data['is_item_testable']) {
 				->addClass('js-popup-row-snmpv3-privpassphrase'),
 			(new CFormField(
 				(new CTextBox('interface[details][privpassphrase]',
-					$data['inputs']['interface']['details']['privpassphrase'], false,
+					$data['inputs']['host']['interface']['details']['privpassphrase'], false,
 					CControllerPopupItemTest::INPUT_MAX_LENGTH
 				))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 			))
@@ -247,18 +248,36 @@ if ($data['is_item_testable']) {
 	}
 
 	$form_grid->addItem([
-		(new CLabel(_('Proxy'), 'label-proxy-hostid'))->addClass('js-proxy-hostid-row'),
-		(new CFormField(
-			(new CSelect('proxy_hostid'))
+		(new CLabel(_('Test with'), 'test_with'))->addClass('js-test-with-row'),
+		(new CFormField([
+			(new CRadioButtonList('test_with', (int) $data['test_with']))
+				->addValue(_('Server'), CControllerPopupItemTest::TEST_WITH_SERVER)
+				->addValue(_('Proxy'), CControllerPopupItemTest::TEST_WITH_PROXY)
 				->setReadonly(!$data['proxies_enabled'])
-				->addOptions(CSelect::createOptionsFromArray([0 => _('(no proxy)')] + $data['proxies']))
-				->setFocusableElementId('label-proxy-hostid')
-				->setValue(array_key_exists('proxy_hostid', $data['inputs']) ? $data['inputs']['proxy_hostid'] : 0)
-				->setId('proxy_hostid')
-				->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
-		))
+				->setModern(),
+			(new CDiv(
+				(new CMultiSelect([
+					'name' => 'proxyid',
+					'object_name' => 'proxies',
+					'multiple' => false,
+					'data' => $data['ms_proxy'],
+					'popup' => [
+						'parameters' => [
+							'srctbl' => 'proxies',
+							'srcfld1' => 'proxyid',
+							'srcfld2' => 'name',
+							'dstfrm' => $form->getName(),
+							'dstfld1' => 'proxyid'
+						]
+					]
+				]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+			))
+				->addClass('js-test-with-proxy')
+				->addStyle($data['test_with'] == CControllerPopupItemTest::TEST_WITH_SERVER ? 'display: none;' : '')
+				->addStyle('margin-top: 5px;')
+		]))
 			->addClass(CFormField::ZBX_STYLE_FORM_FIELD_FLUID)
-			->addClass('js-proxy-hostid-row'),
+			->addClass('js-test-with-row'),
 
 		(new CFormField(
 			(new CSimpleButton(_('Get value')))
@@ -272,11 +291,17 @@ if ($data['is_item_testable']) {
 }
 
 $form_grid->addItem([
-	new CLabel(_('Value'), 'value'),
+	new CLabel([
+		_('Value'),
+		makeWarningIcon('#{warning}')
+			->setId('value_warning')
+			->addStyle('display: none;')
+	], 'value'),
 	new CFormField(
 		(new CMultilineInput('value', '', [
 			'disabled' => false,
-			'readonly' => false
+			'readonly' => false,
+			'use_tab' => false
 		]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 	),
 
@@ -289,13 +314,22 @@ $form_grid->addItem([
 
 	($data['test_type'] == CControllerPopupItemTestEdit::ZBX_TEST_TYPE_LLD)
 		? null
-		: (new CFormField((new CCheckBox('not_supported'))->setLabel(_('Not supported'))))
-			->addClass(CFormField::ZBX_STYLE_FORM_FIELD_FLUID),
+		: (new CFormField([
+			(new CCheckBox('not_supported'))->setLabel(_('Not supported'))->setChecked((bool) $data['not_supported']),
+			(new CDiv([
+				(new CLabel(_('Error'), 'runtime_error_match'))->setFor('runtime_error'),
+				(new CMultilineInput('runtime_error', '', ['readonly' => false, 'use_tab' => false]))
+			]))
+		]))
+			->addClass(CFormField::ZBX_STYLE_FORM_FIELD_FLUID)
+			->addClass('runtime-error-fields')
+			->addStyle('width: '.ZBX_TEXTAREA_STANDARD_WIDTH.'px;'),
 
 	new CLabel(_('Previous value'), 'prev_item_value'),
 	new CFormField(
 		(new CMultilineInput('prev_value', '', [
-			'disabled' => !$data['show_prev']
+			'disabled' => !$data['show_prev'],
+			'use_tab' => false
 		]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 	),
 
@@ -383,67 +417,54 @@ if ($data['show_final_result']) {
 $form->addItem($form_grid);
 
 // Enable form submitting on Enter.
-$form->addItem((new CSubmitButton(null))->addClass(ZBX_STYLE_FORM_SUBMIT_HIDDEN));
+$form->addItem((new CSubmitButton())->addClass(ZBX_STYLE_FORM_SUBMIT_HIDDEN));
 
-$templates = [
-	(new CTag('script', true))
-		->setAttribute('type', 'text/x-jquery-tmpl')
-		->setId('preprocessing-step-error-icon')
-		->addItem(makeErrorIcon('#{error}')),
-	(new CTag('script', true))
-		->setAttribute('type', 'text/x-jquery-tmpl')
-		->setId('preprocessing-gray-label')
-		->addItem(
-			(new CDiv('#{label}'))
-				->addStyle('margin-top: 5px;')
-				->addClass(ZBX_STYLE_GREY)
-		),
-	(new CTag('script', true))
-		->setAttribute('type', 'text/x-jquery-tmpl')
-		->setId('preprocessing-step-result')
-		->addItem(
+$form->addItem([
+	(new CTemplateTag('preprocessing-step-error-icon'))->addItem(
+		makeErrorIcon('#{error}')
+	),
+	(new CTemplateTag('preprocessing-gray-label'))->addItem(
+		(new CDiv('#{label}'))
+			->addStyle('margin-top: 5px;')
+			->addClass(ZBX_STYLE_GREY)
+	),
+	(new CTemplateTag('preprocessing-step-result'))->addItem(
+		(new CDiv(
+			(new CSpan('#{result}'))
+				->addClass(ZBX_STYLE_LINK_ACTION)
+				->setHint('#{result_hint}', 'hintbox-wrap')
+		))
+			->addStyle('max-width: '.ZBX_TEXTAREA_STANDARD_WIDTH.'px;')
+			->addClass('item-test-result')
+			->addClass(ZBX_STYLE_OVERFLOW_ELLIPSIS)
+	),
+	(new CTemplateTag('preprocessing-step-result-warning'))->addItem(
+		(new CDiv([
+			(new CDiv('#{result}'))
+				->addClass(ZBX_STYLE_LINK_ACTION)
+				->addClass(ZBX_STYLE_OVERFLOW_ELLIPSIS)
+				->setHint('#{result_hint}', 'hintbox-wrap'),
+			makeWarningIcon('#{warning}')
+		]))
+			->addStyle('max-width: '.ZBX_TEXTAREA_STANDARD_WIDTH.'px;')
+			->addClass('item-test-result')
+	),
+	(new CTemplateTag('preprocessing-step-action-done'))->addItem(
+		(new CDiv([
+			'#{action_name} ',
 			(new CDiv(
-				(new CSpan('#{result}'))
+				(new CSpan('#{failed}'))
 					->addClass(ZBX_STYLE_LINK_ACTION)
-					->setHint('#{result}', 'hintbox-wrap')
-			))
+					->setHint('#{failed_hint}', 'hintbox-wrap')
+				))
 				->addStyle('max-width: '.ZBX_TEXTAREA_STANDARD_WIDTH.'px;')
 				->addClass(ZBX_STYLE_OVERFLOW_ELLIPSIS)
-		),
-	(new CTag('script', true))
-		->setAttribute('type', 'text/x-jquery-tmpl')
-		->setId('preprocessing-step-result-warning')
-		->addItem(
-			(new CDiv([
-				(new CDiv('#{result}'))
-					->addClass(ZBX_STYLE_LINK_ACTION)
-					->addClass(ZBX_STYLE_OVERFLOW_ELLIPSIS)
-					->setHint('#{result}', 'hintbox-wrap'),
-				NBSP(),
-				makeWarningIcon('#{warning}')
-					->addStyle('margin: 0')
-			]))
-				->addStyle('max-width: '.ZBX_TEXTAREA_STANDARD_WIDTH.'px; display: inline-flex;')
-		),
-	(new CTag('script', true))
-		->setAttribute('type', 'text/x-jquery-tmpl')
-		->setId('preprocessing-step-action-done')
-		->addItem(
-			(new CDiv([
-				'#{action_name} ',
-				(new CDiv(
-					(new CSpan('#{failed}'))
-						->addClass(ZBX_STYLE_LINK_ACTION)
-						->setHint('#{failed}', 'hintbox-wrap')
-				))
-					->addStyle('max-width: '.ZBX_TEXTAREA_STANDARD_WIDTH.'px;')
-					->addClass(ZBX_STYLE_OVERFLOW_ELLIPSIS)
-					->addClass(ZBX_STYLE_REL_CONTAINER)
-			]))
-				->addStyle('margin-top: 1px;')
-				->addClass(ZBX_STYLE_GREY)
-		)
-];
+				->addClass(ZBX_STYLE_REL_CONTAINER)
+		]))
+			->addStyle('margin-top: 1px;')
+			->addClass(ZBX_STYLE_GREY)
+	)
+]);
 
 $warning_box = $data['show_warning']
 	? makeMessageBox(ZBX_STYLE_MSG_WARNING, [[
@@ -455,7 +476,7 @@ $output = [
 	'header' => $data['title'],
 	'doc_url' => CDocHelper::getUrl(CDocHelper::POPUP_TEST_EDIT),
 	'script_inline' => $this->readJsFile('popup.itemtestedit.view.js.php'),
-	'body' => (new CDiv([$warning_box, $form, $templates]))->toString(),
+	'body' => (new CDiv([$warning_box, $form]))->toString(),
 	'cancel_action' => 'return saveItemTestInputs();',
 	'buttons' => [
 		[
