@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -29,14 +24,14 @@ $url = (new CUrl('zabbix.php'))
 	->getUrl();
 
 $token_form = (new CForm('post', $url))
-	->addItem((new CVar(CCsrfTokenHelper::CSRF_TOKEN_NAME, CCsrfTokenHelper::get('token')))->removeId())
+	->addItem((new CVar(CSRF_TOKEN_NAME, CCsrfTokenHelper::get('token')))->removeId())
 	->setId('token_form')
 	->setName('token')
 	->addVar('admin_mode', $data['admin_mode'])
 	->addVar('tokenid', $data['tokenid']);
 
 // Enable form submitting on Enter.
-$token_form->addItem((new CSubmitButton(null))->addClass(ZBX_STYLE_FORM_SUBMIT_HIDDEN));
+$token_form->addItem((new CSubmitButton())->addClass(ZBX_STYLE_FORM_SUBMIT_HIDDEN));
 
 if ($data['admin_mode'] === '0') {
 	$token_form->addVar('userid', CWebUser::$data['userid']);
@@ -99,7 +94,7 @@ $token_from_grid->addItem([
 		(new CLabel(_('Expires at'), 'expires_at'))->setAsteriskMark(),
 		new CFormField(
 			(new CDateSelector('expires_at', $data['expires_at']))
-				->setDateFormat(DATE_TIME_FORMAT_SECONDS)
+				->setDateFormat(ZBX_FULL_DATE_TIME)
 				->setPlaceholder(_('YYYY-MM-DD hh:mm:ss'))
 				->setAriaRequired()
 				->setId('expires-at-row')
