@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -26,7 +21,7 @@ require_once dirname(__FILE__).'/include/forms.inc.php';
 
 $page['title'] = _('Configuration of web monitoring');
 $page['file'] = 'httpconf.php';
-$page['scripts'] = ['class.tagfilteritem.js'];
+$page['scripts'] = ['class.tagfilteritem.js', 'items.js', 'multilineinput.js'];
 
 require_once dirname(__FILE__).'/include/page_header.php';
 
@@ -47,7 +42,8 @@ $fields = [
 	'agent_other'     => [T_ZBX_STR, O_OPT, null,	null,
 		'(isset({add}) || isset({update})) && isset({agent}) && {agent} == '.ZBX_AGENT_OTHER
 	],
-	'pairs'           => [T_ZBX_STR, O_OPT, P_NO_TRIM|P_ONLY_TD_ARRAY,	null,	null],
+	'variables'			=> [T_ZBX_STR, O_OPT, P_NO_TRIM|P_ONLY_TD_ARRAY,	null,	null],
+	'headers'			=> [T_ZBX_STR, O_OPT, P_NO_TRIM|P_ONLY_TD_ARRAY,	null,	null],
 	'steps'           => [null,      O_OPT, P_NO_TRIM|P_ONLY_TD_ARRAY,	null,	'isset({add}) || isset({update})', _('Steps')],
 	'authentication'  => [T_ZBX_INT, O_OPT, null,
 								IN([ZBX_HTTP_AUTH_NONE, ZBX_HTTP_AUTH_BASIC, ZBX_HTTP_AUTH_NTLM, ZBX_HTTP_AUTH_KERBEROS,
@@ -204,51 +200,24 @@ elseif (hasRequest('add') || hasRequest('update')) {
 		$messageFalse = _('Cannot add web scenario');
 	}
 
+	$result = false;
+
 	try {
 		DBstart();
 
 		$steps = getRequest('steps', []);
-		$field_names = ['headers', 'variables', 'post_fields', 'query_fields'];
-		$i = 1;
 
+		$i = 1;
 		foreach ($steps as &$step) {
 			$step['no'] = $i++;
-			$step['follow_redirects'] = $step['follow_redirects']
-				? HTTPTEST_STEP_FOLLOW_REDIRECTS_ON
-				: HTTPTEST_STEP_FOLLOW_REDIRECTS_OFF;
 
-			foreach ($field_names as $field_name) {
-				$step[$field_name] = [];
-			}
-
-			if (array_key_exists('pairs', $step)) {
-				foreach ($field_names as $field_name) {
-					foreach ($step['pairs'] as $pair) {
-						if (array_key_exists('type', $pair) && $field_name === $pair['type']) {
-							$name = array_key_exists('name', $pair) ? trim($pair['name']) : '';
-							$value = array_key_exists('value', $pair) ? trim($pair['value']) : '';
-
-							if ($name === '' && $value === '') {
-								continue;
-							}
-
-							$step[$field_name][] = [
-								'name' => $name,
-								'value' => $value
-							];
-						}
-					}
-				}
-				unset($step['pairs']);
+			foreach (['query_fields', 'variables', 'headers'] as $field) {
+				$step[$field] = array_key_exists($field, $step) ? $step[$field] : [];
 			}
 
 			if ($step['post_type'] == ZBX_POSTTYPE_FORM) {
-				$step['posts'] = $step['post_fields'];
+				$step['posts'] = array_key_exists('post_fields', $step) ? $step['post_fields'] : [];
 			}
-			else {
-				$step['posts'] = trim($step['posts']);
-			}
-
 			unset($step['post_fields'], $step['post_type']);
 		}
 		unset($step);
@@ -260,7 +229,7 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			'delay' => getRequest('delay', DB::getDefault('httptest', 'delay')),
 			'retries' => $_REQUEST['retries'],
 			'status' => hasRequest('status') ? HTTPTEST_STATUS_ACTIVE : HTTPTEST_STATUS_DISABLED,
-			'agent' => hasRequest('agent_other') ? getRequest('agent_other') : getRequest('agent'),
+			'agent' => getRequest('agent') == ZBX_AGENT_OTHER ? getRequest('agent_other') : getRequest('agent'),
 			'variables' => [],
 			'http_proxy' => $_REQUEST['http_proxy'],
 			'steps' => $steps,
@@ -275,19 +244,16 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			'tags' => $tags
 		];
 
-		foreach (getRequest('pairs', []) as $pair) {
-			if (array_key_exists('type', $pair) && in_array($pair['type'], ['variables', 'headers'])) {
-				$name = array_key_exists('name', $pair) ? trim($pair['name']) : '';
-				$value = array_key_exists('value', $pair) ? trim($pair['value']) : '';
+		foreach (['variables', 'headers'] as $pair_type) {
+			foreach (getRequest($pair_type, []) as $pair) {
+				$pair['name'] = array_key_exists('name', $pair) ? trim($pair['name']) : '';
+				$pair['value'] = array_key_exists('value', $pair) ? trim($pair['value']) : '';
 
-				if ($name === '' && $value === '') {
+				if ($pair['name'] === '' && $pair['value'] === '') {
 					continue;
 				}
 
-				$httpTest[$pair['type']][] = [
-					'name' => $name,
-					'value' => $value
-				];
+				$httpTest[$pair_type][] = $pair;
 			}
 		}
 
@@ -353,11 +319,11 @@ elseif (hasRequest('add') || hasRequest('update')) {
 				}
 			}
 
-			$httpTest['httptestid'] = $httpTestId = $_REQUEST['httptestid'];
+			$httpTest['httptestid'] = $_REQUEST['httptestid'];
+
+			$result = (bool) API::HttpTest()->update($httpTest);
 
-			$result = API::HttpTest()->update($httpTest);
 			if (!$result) {
-
 				throw new Exception();
 			}
 			else {
@@ -370,30 +336,30 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			}
 			unset($step);
 
-			$result = API::HttpTest()->create($httpTest);
+			$result = (bool) API::HttpTest()->create($httpTest);
+
 			if (!$result) {
 				throw new Exception();
 			}
 			else {
 				uncheckTableRows(getRequest('hostid'));
 			}
-			$httpTestId = reset($result['httptestids']);
 		}
 
 		unset($_REQUEST['form']);
 		show_messages(true, $messageTrue);
-		DBend(true);
 	}
 	catch (Exception $e) {
-		DBend(false);
-
-
 		$msg = $e->getMessage();
-		if (!empty($msg)) {
+
+		if ($msg !== '') {
 			error($msg);
 		}
+
 		show_messages(false, null, $messageFalse);
 	}
+
+	$result = DBend($result);
 }
 elseif (hasRequest('action') && str_in_array(getRequest('action'), ['httptest.massenable', 'httptest.massdisable'])
 		&& hasRequest('group_httptestid') && is_array(getRequest('group_httptestid'))) {
@@ -429,7 +395,7 @@ elseif (hasRequest('action') && str_in_array(getRequest('action'), ['httptest.ma
 	}
 
 	if (hasRequest('backurl')) {
-		$response = new CControllerResponseRedirect(getRequest('backurl'));
+		$response = new CControllerResponseRedirect(new CUrl(getRequest('backurl')));
 		$response->redirect();
 	}
 }
@@ -451,7 +417,12 @@ elseif (hasRequest('action') && getRequest('action') === 'httptest.massdelete'
 	if ($result) {
 		uncheckTableRows(getRequest('hostid'));
 	}
-	show_messages($result, _('Web scenario deleted'), _('Cannot delete web scenario'));
+
+	$web_scenarios_count = count(getRequest('group_httptestid'));
+	$messageSuccess = _n('Web scenario deleted', 'Web scenarios deleted', $web_scenarios_count);
+	$messageFailed = _n('Cannot delete web scenario', 'Cannot delete web scenarios', $web_scenarios_count);
+
+	show_messages($result, $messageSuccess, $messageFailed);
 }
 
 if (hasRequest('action') && hasRequest('group_httptestid') && !$result) {
@@ -488,9 +459,9 @@ if (isset($_REQUEST['form'])) {
 
 	if (hasRequest('httptestid')) {
 		$db_httptests = API::HttpTest()->get([
-			'output' => ['name', 'delay', 'retries', 'status', 'agent', 'authentication',
-				'http_user', 'http_password', 'http_proxy', 'templateid', 'verify_peer', 'verify_host', 'ssl_cert_file',
-				'ssl_key_file', 'ssl_key_password', 'headers', 'variables'
+			'output' => ['httptestid', 'name', 'delay', 'status', 'agent', 'authentication', 'http_user',
+				'http_password', 'templateid', 'http_proxy', 'retries', 'ssl_cert_file', 'ssl_key_file',
+				'ssl_key_password', 'verify_peer', 'verify_host', 'headers', 'variables'
 			],
 			'selectSteps' => ['httpstepid', 'name', 'no', 'url', 'timeout', 'posts', 'required', 'status_codes',
 				'follow_redirects', 'retrieve_mode', 'headers', 'variables', 'query_fields', 'post_type'
@@ -521,28 +492,6 @@ if (isset($_REQUEST['form'])) {
 			}
 		}
 
-		// Used for both, Scenario and Steps pairs.
-		$id = 1;
-		$data['pairs'] = [];
-
-		$fields = [
-			'headers' => 'headers',
-			'variables' => 'variables'
-		];
-
-		CArrayHelper::sort($db_httptest['variables'], ['name']);
-
-		foreach ($fields as $type => $field_name) {
-			foreach ($db_httptest[$field_name] as $pair) {
-				$data['pairs'][] = [
-					'id' => $id++,
-					'type' => $type,
-					'name' => $pair['name'],
-					'value' => $pair['value']
-				];
-			}
-		}
-
 		$data['authentication'] = $db_httptest['authentication'];
 		$data['http_user'] = $db_httptest['http_user'];
 		$data['http_password'] = $db_httptest['http_password'];
@@ -553,40 +502,21 @@ if (isset($_REQUEST['form'])) {
 		$data['ssl_cert_file'] = $db_httptest['ssl_cert_file'];
 		$data['ssl_key_file'] = $db_httptest['ssl_key_file'];
 		$data['ssl_key_password'] = $db_httptest['ssl_key_password'];
-		$data['steps'] = $db_httptest['steps'];
-		CArrayHelper::sort($data['steps'], ['no']);
 
-		$fields = [
-			'headers' => 'headers',
-			'variables' => 'variables',
-			'query_fields' => 'query_fields',
-			'post_fields' => 'posts'
-		];
+		$data['variables'] = $db_httptest['variables'];
+		$data['headers'] = $db_httptest['headers'];
+
+		CArrayHelper::sort($db_httptest['steps'], ['no']);
+		$data['steps'] = array_values($db_httptest['steps']);
 
 		foreach ($data['steps'] as &$step) {
-			$step['pairs'] = [];
+			if ($step['post_type'] == ZBX_POSTTYPE_FORM) {
+				$step['post_fields'] = $step['posts'];
+				$step['posts'] = '';
+			}
 
 			CArrayHelper::sort($step['variables'], ['name']);
-
-			foreach ($fields as $type => $field_name) {
-				if ($field_name !== 'posts' || $step['post_type'] == ZBX_POSTTYPE_FORM) {
-					foreach ($step[$field_name] as $pair) {
-						$step['pairs'][] = [
-							'id' => $id++,
-							'type' => $type,
-							'name' => $pair['name'],
-							'value' => $pair['value']
-						];
-					}
-
-					if ($field_name === 'posts') {
-						$step['posts'] = '';
-					}
-					else {
-						unset($step[$field_name]);
-					}
-				}
-			}
+			$step['variables'] = array_values($step['variables']);
 		}
 		unset($step);
 
@@ -626,25 +556,9 @@ if (isset($_REQUEST['form'])) {
 		$data['ssl_cert_file'] = getRequest('ssl_cert_file');
 		$data['ssl_key_file'] = getRequest('ssl_key_file');
 		$data['ssl_key_password'] = getRequest('ssl_key_password');
-		$data['pairs'] = array_values(getRequest('pairs', []));
-	}
-
-	$i = 1;
-	foreach($data['steps'] as $stepid => $step) {
-		$pairs_grouped = [
-			'query_fields' => [],
-			'post_fields' => [],
-			'variables' => [],
-			'headers' => []
-		];
-
-		if (array_key_exists('pairs', $step)) {
-			foreach ($step['pairs'] as $field) {
-				$pairs_grouped[$field['type']][] = $field;
-			}
-			$data['steps'][$stepid]['pairs'] = $pairs_grouped;
-		}
-		$data['steps'][$stepid]['no'] = $i++;
+		$data['variables'] = getRequest('variables', []);
+		$data['headers'] = array_values(getRequest('headers', []));
+		$data['steps'] = array_values(getRequest('steps', []));
 	}
 
 	if ($db_httptest) {
@@ -682,6 +596,18 @@ if (isset($_REQUEST['form'])) {
 		]);
 	}
 
+	if ($data['variables']) {
+		CArrayHelper::sort($data['variables'], ['name']);
+		$data['variables'] = array_values($data['variables']);
+	}
+	else {
+		$data['variables'] = [['name' => '', 'value' => '']];
+	}
+
+	if (!$data['headers']) {
+		$data['headers'] = [['name' => '', 'value' => '']];
+	}
+
 	$data['tags'] = $tags;
 	if (!$data['tags']) {
 		$data['tags'][] = ['tag' => '', 'value' => ''];
