@@ -1,6 +1,6 @@
 <?php declare(strict_types = 0);
 /*
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -697,12 +697,21 @@ class ZBase {
 				'stylesheet' => [
 					'files' => []
 				],
-				'web_layout_mode' => ZBX_LAYOUT_NORMAL,
-				'config' => [
+				'web_layout_mode' => ZBX_LAYOUT_NORMAL
+			];
+
+			try {
+				$layout_data_defaults['config'] = [
 					'server_check_interval' => CSettingsHelper::get(CSettingsHelper::SERVER_CHECK_INTERVAL),
 					'x_frame_options' => CSettingsHelper::get(CSettingsHelper::X_FRAME_OPTIONS)
-				]
-			];
+				];
+			}
+			catch (Throwable $e) {
+				$layout_data_defaults['config'] = [
+					'server_check_interval' => DB::getDefault('config', 'server_check_interval'),
+					'x_frame_options' => DB::getDefault('config', 'x_frame_options')
+				];
+			}
 
 			if ($router->getView() !== null && $response->isViewEnabled()) {
 				$this->view = new CView($router->getView(), $response->getData());
