@@ -1,6 +1,6 @@
 <?php declare(strict_types = 0);
 /*
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -16,7 +16,7 @@
 
 class CRegexHelper {
 
-	public static function expression_type2str(int $type = null) {
+	public static function expression_type2str(?int $type = null) {
 		$types = [
 			EXPRESSION_TYPE_INCLUDED => _('Character string included'),
 			EXPRESSION_TYPE_ANY_INCLUDED => _('Any character string included'),
