@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -112,7 +107,8 @@ class CScreenHttpTest extends CScreenBase {
 				_('Last check'),
 				_('Status'),
 				_('Tags')
-			]);
+			])
+			->setPageNavigation($paging);
 
 		foreach ($httptests as $key => $httptest) {
 			if (array_key_exists('lastfailedstep', $httptest) && $httptest['lastfailedstep'] !== null) {
@@ -145,15 +141,20 @@ class CScreenHttpTest extends CScreenBase {
 			}
 
 			$table->addRow(new CRow([
-				(new CLinkAction($httptest['hostname']))->setMenuPopup(CMenuPopupHelper::getHost($httptest['hostid'])),
-				new CLink($httptest['name'], 'httpdetails.php?httptestid='.$httptest['httptestid']),
+				(new CCol(
+					(new CLinkAction($httptest['hostname']))
+						->setMenuPopup(CMenuPopupHelper::getHost($httptest['hostid']))
+				))->addClass(ZBX_STYLE_WORDBREAK),
+				(new CCol(
+					new CLink($httptest['name'], 'httpdetails.php?httptestid='.$httptest['httptestid'])
+				))->addClass(ZBX_STYLE_WORDBREAK),
 				$httptest['steps'],
 				$lastcheck,
-				$status,
+				(new CCol($status))->addClass(ZBX_STYLE_WORDBREAK),
 				array_key_exists($key, $tags) ? $tags[$key] : ''
 			]));
 		}
 
-		return $this->getOutput([$table, $paging], true, $this->data);
+		return $this->getOutput($table, true, $this->data);
 	}
 }
