@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -71,14 +66,14 @@ function isWritableHostGroups(array $groupids) {
  *
  * @return array
  */
-function getSubGroups(array $groupids, array &$ms_groups = null, string $context = 'host') {
+function getSubGroups(array $groupids, ?array &$ms_groups = null, string $context = 'host', array $options = []) {
 	$entity = $context === 'host' ? API::HostGroup() : API::TemplateGroup();
 	$db_groups = $groupids
 		? $entity->get([
 			'output' => ['groupid', 'name'],
 			'groupids' => $groupids,
 			'preservekeys' => true
-		])
+		] + $options)
 		: [];
 
 	if ($ms_groups !== null) {
@@ -98,7 +93,7 @@ function getSubGroups(array $groupids, array &$ms_groups = null, string $context
 			'searchByAny' => true,
 			'startSearch' => true,
 			'preservekeys' => true
-		]);
+		] + $options);
 	}
 
 	return array_keys($db_groups);
@@ -113,7 +108,7 @@ function getSubGroups(array $groupids, array &$ms_groups = null, string $context
  *
  * @return array
  */
-function getTemplateSubGroups(array $template_groupids, array &$ms_template_groups = null, array $options = []) {
+function getTemplateSubGroups(array $template_groupids, ?array &$ms_template_groups = null, array $options = []) {
 	$db_groups = $template_groupids
 		? API::TemplateGroup()->get([
 				'output' => ['groupid', 'name'],
