@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -58,6 +53,9 @@ function IN($array, $var = '') {
 	return 'str_in_array({'.$var.'},array('.$array.'))&&';
 }
 
+/**
+ * @deprecated
+ */
 function HEX($var = null) {
 	return 'preg_match("/^([a-zA-Z0-9]+)$/",{'.$var.'})&&';
 }
@@ -142,17 +140,34 @@ function unset_all() {
 }
 
 function check_type(&$field, $flags, &$var, $type, $caption = null) {
-	global $DB;
-
 	if ($caption === null) {
 		$caption = $field;
 	}
 
-	if (is_array($var) && $type != T_ZBX_RANGE_TIME) {
+	$is_array_flag = ($flags & P_ONLY_ARRAY);
+	$is_td_array_flag = ($flags & P_ONLY_TD_ARRAY);
+	$has_array_flag = $is_array_flag || $is_td_array_flag;
+
+	if (is_array($var) && $type != T_ZBX_RANGE_TIME && $has_array_flag) {
 		$err = ZBX_VALID_OK;
 
-		foreach ($var as $v) {
-			$err |= check_type($field, $flags, $v, $type);
+		if ($flags & P_ONLY_ARRAY) {
+			$flags &= ~P_ONLY_ARRAY;
+		}
+
+		if ($flags & P_ONLY_TD_ARRAY) {
+			$flags &= ~P_ONLY_TD_ARRAY;
+			$flags |= P_ONLY_ARRAY;
+		}
+
+		if ($flags & P_ONLY_ARRAY || $type !== null) {
+			foreach ($var as $v) {
+				$err = check_type($field, $flags, $v, $type);
+
+				if ($err != ZBX_VALID_OK) {
+					break;
+				}
+			}
 		}
 
 		return $err;
@@ -161,6 +176,17 @@ function check_type(&$field, $flags, &$var, $type, $caption = null) {
 	$error = false;
 	$message = '';
 
+	if ($has_array_flag) {
+		if (!is_array($var)) {
+			error(_s('Field "%1$s" is not correct: %2$s.', $caption, _('an array is expected')));
+			return ZBX_VALID_ERROR;
+		}
+	}
+	elseif (is_array($var)) {
+		error(_s('Field "%1$s" is not correct: %2$s.', $caption, _('invalid data type')));
+		return ZBX_VALID_ERROR;
+	}
+
 	if ($type == T_ZBX_INT) {
 		if (!zbx_is_int($var)) {
 			$error = true;
@@ -168,7 +194,7 @@ function check_type(&$field, $flags, &$var, $type, $caption = null) {
 		}
 	}
 	elseif ($type == T_ZBX_DBL) {
-		$number_parser = new CNumberParser(['with_suffix' => false]);
+		$number_parser = new CNumberParser();
 
 		if ($number_parser->parse($var) != CParser::PARSE_SUCCESS) {
 			$error = true;
@@ -177,23 +203,9 @@ function check_type(&$field, $flags, &$var, $type, $caption = null) {
 
 		$value = $number_parser->calcValue();
 
-		if ($DB['DOUBLE_IEEE754']) {
-			if (abs($value) > ZBX_FLOAT_MAX) {
-				$error = true;
-				$message = _s('Field "%1$s" is not correct: %2$s', $caption, _('a number is too large'));
-			}
-		}
-		else {
-			if (abs($value) >= 1E+16) {
-				$error = true;
-				$message = _s('Field "%1$s" is not correct: %2$s', $caption, _('a number is too large'));
-			}
-			elseif ($value != round($value, 4)) {
-				$error = true;
-				$message = _s('Field "%1$s" is not correct: %2$s', $caption,
-					_('a number has too many fractional digits')
-				);
-			}
+		if (abs($value) > ZBX_FLOAT_MAX) {
+			$error = true;
+			$message = _s('Field "%1$s" is not correct: %2$s', $caption, _('a number is too large'));
 		}
 	}
 	elseif ($type == T_ZBX_STR) {
@@ -201,6 +213,11 @@ function check_type(&$field, $flags, &$var, $type, $caption = null) {
 			$error = true;
 			$message = _s('Field "%1$s" is not string.', $caption);
 		}
+		elseif (zbx_mb_check_encoding($var, 'UTF-8') !== true) {
+			error(_s('Field "%1$s" is not correct: %2$s.', $caption, _('invalid byte sequence in UTF-8')));
+
+			return ZBX_VALID_ERROR;
+		}
 	}
 	elseif ($type == T_ZBX_TU) {
 		$simple_interval_parser = new CSimpleIntervalParser([
@@ -304,9 +321,12 @@ function check_field(&$fields, &$field, $checks) {
 			return ZBX_VALID_OK;
 		}
 		elseif ($flags & P_ACT) {
-			if (!isset($_REQUEST['sid'])
-					|| (array_key_exists(ZBX_SESSION_NAME, $_COOKIE)
-							&& $_REQUEST['sid'] != substr($_COOKIE[ZBX_SESSION_NAME], 16, 16))) {
+			$action = APP::Component()->router->getAction();
+
+			$csrf_token_form = getRequest(CSRF_TOKEN_NAME, '');
+
+			if (!isRequestMethod('post') || !is_string($csrf_token_form) || $csrf_token_form === ''
+					|| !CCsrfTokenHelper::check($csrf_token_form, $action)) {
 				info(_('Operation cannot be performed due to unauthorized request.'));
 				return ZBX_VALID_ERROR;
 			}
@@ -364,21 +384,23 @@ function invalid_url($msg = null) {
 	}
 
 	// required global parameters for correct including page_header.php
-	global $DB, $ZBX_MESSAGES, $page;
+	global $DB;
 
 	// backup messages before including page_header.php
-	$temp = $ZBX_MESSAGES;
-	$ZBX_MESSAGES = [];
+	$messages_backup = CMessageHelper::getMessages();
+	CMessageHelper::clear();
 
 	require_once dirname(__FILE__).'/page_header.php';
 
 	// Rollback reset messages.
-	$ZBX_MESSAGES = $temp;
+	foreach ($messages_backup as $message) {
+		CMessageHelper::addMessage($message);
+	}
 
 	unset_all();
 	show_error_message($msg);
 
-	(new CWidget())->show();
+	(new CHtmlPage())->show();
 	require_once dirname(__FILE__).'/page_footer.php';
 }
 
@@ -392,7 +414,6 @@ function invalid_url($msg = null) {
 function check_fields_raw(&$fields) {
 	// VAR	TYPE	OPTIONAL	FLAGS	VALIDATION	EXCEPTION
 	$system_fields = [
-		'sid' =>			[T_ZBX_STR, O_OPT, P_SYS, HEX(),		null],
 		'triggers_hash' =>	[T_ZBX_STR, O_OPT, P_SYS, NOT_EMPTY,	null],
 		'print' =>			[T_ZBX_INT, O_OPT, P_SYS, IN('1'),		null],
 		'page' =>			[T_ZBX_INT, O_OPT, P_SYS, null,		null]	// paging
@@ -450,14 +471,21 @@ function validateTimeSelectorPeriod($from, $to) {
 	}
 
 	$ts = [];
+	$ts['now'] = time();
 	$range_time_parser = new CRangeTimeParser();
 
 	foreach (['from' => $from, 'to' => $to] as $field => $value) {
 		$range_time_parser->parse($value);
-		$ts[$field] = $range_time_parser->getDateTime($field === 'from')->getTimestamp();
+		$ts[$field] = $range_time_parser
+			->getDateTime($field === 'from')
+			->getTimestamp();
 	}
 
 	$period = $ts['to'] - $ts['from'] + 1;
+	$range_time_parser->parse('now-'.CSettingsHelper::get(CSettingsHelper::MAX_PERIOD));
+	$max_period = 1 + $ts['now'] - $range_time_parser
+		->getDateTime(true)
+		->getTimestamp();
 
 	if ($period < ZBX_MIN_PERIOD) {
 		error(_n('Minimum time period to display is %1$s minute.',
@@ -466,9 +494,9 @@ function validateTimeSelectorPeriod($from, $to) {
 
 		invalid_url();
 	}
-	elseif ($period > ZBX_MAX_PERIOD) {
+	elseif ($period > $max_period) {
 		error(_n('Maximum time period to display is %1$s day.',
-			'Maximum time period to display is %1$s days.', (int) (ZBX_MAX_PERIOD / SEC_PER_DAY)
+			'Maximum time period to display is %1$s days.', (int) round($max_period / SEC_PER_DAY)
 		));
 
 		invalid_url();
@@ -500,7 +528,8 @@ function validateNumber($value, $min = null, $max = null) {
 }
 
 function validateUserMacro($value) {
-	return ((new CUserMacroParser())->parse($value) == CParser::PARSE_SUCCESS);
+	return (new CUserMacroParser())->parse($value) == CParser::PARSE_SUCCESS
+		|| (new CUserMacroFunctionParser())->parse($value) == CParser::PARSE_SUCCESS;
 }
 
 /**
@@ -560,6 +589,7 @@ function validateDateInterval($year, $month, $day) {
  * @param array  $options
  * @param bool   $options['usermacros']
  * @param bool   $options['lldmacros']
+ * @param bool   $options['with_year']
  *
  * @return bool
  */
@@ -569,7 +599,7 @@ function validateTimeUnit($value, $min, $max, $allow_zero, &$error, array $optio
 
 	if ($simple_interval_parser->parse($value) == CParser::PARSE_SUCCESS) {
 		if ($value[0] !== '{') {
-			$value = timeUnitToSeconds($value);
+			$value = timeUnitToSeconds($value, array_key_exists('with_year', $options) ? $options['with_year'] : false);
 
 			if ($allow_zero && $value == 0) {
 				return true;
