@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -83,15 +78,18 @@ elseif (!$data['has_serviceid']) {
 		}
 	}
 
-	$report->setFooter(
-		(new CCol(_s('Displaying %1$s of %2$s found', $num_rows_displayed,
-			count($data['services']) > $data['search_limit']
-				? $data['search_limit'].'+'
-				: count($data['services'])
-		)))
-			->setColSpan($report->getNumCols())
-			->addClass(ZBX_STYLE_LIST_TABLE_FOOTER)
-	);
+	$total = count($data['services']) > $data['search_limit']
+		? $data['search_limit'].'+'
+		: count($data['services']);
+
+	if ($total > 0) {
+		$report->setFooter(
+			(new CCol(_s('Displaying %1$s of %2$s found', $num_rows_displayed, $total)))
+				->setColSpan($report->getNumCols())
+				->addClass(ZBX_STYLE_LIST_TABLE_FOOTER)
+		);
+	}
+
 }
 else {
 	$report->setHeader([
